@@ -6,11 +6,12 @@ import warnings
 
 from bson import ObjectId
 
+from ._compat import get_next, iterkeys, itervalues, reraise, with_metaclass
 from .exceptions import MultipleDocumentsFound, NoDocumentFound
 from .meta import Meta
 from .query import Q, QuerySet
 from .utils import (current_datetime, get_nested_key, guarantee_object_id,
-                    is_atomic, map_fields, remove_nested_key,
+                    ignored, is_atomic, map_fields, remove_nested_key,
                     set_write_concern, update_nested_keys)
 
 __all__ = ('Model',)
@@ -24,10 +25,8 @@ __all__ = ('Model',)
 # update before the write is considered successful.
 
 class ModelMetaClass(type):
-    """Define :class:`Model`
 
-    .. versionadded:: 0.1.0
-    """
+    """Define :class:`Model`."""
 
     def __new__(cls, name, bases, attrs):
         new_new = super(ModelMetaClass, cls).__new__
@@ -59,10 +58,7 @@ class ModelMetaClass(type):
         return new_class
 
     def addattr(self, name, value):
-        """Assigns attributes to the class.
-
-        .. versionadded:: 0.1.0
-        """
+        """Assign attributes to the class."""
 
         if hasattr(value, 'add_to_original'):
             value.add_to_original(self, name)
@@ -70,22 +66,16 @@ class ModelMetaClass(type):
             setattr(self, name, value)
 
 
-class Model(object):
-    """The base class for all Simon models
+class Model(with_metaclass(ModelMetaClass)):
 
-    .. versionadded:: 0.1.0
-    """
-
-    __metaclass__ = ModelMetaClass
+    """Base class for all Simon models."""
 
     def __init__(self, **fields):
-        """Assigns all keyword arguments to the object's document.
+        """Assign all keyword arguments to the object's document.
 
         :param \*\*fields: Keyword arguments to add to the document.
         :type \*\*fields: \*\*kwargs.
-        :raises: :class:`~simon.exceptions.ConnectionError`
 
-        .. versionadded:: 0.1.0
         """
 
         # Assign an empty dictionary to _document so that it can be
@@ -100,12 +90,11 @@ class Model(object):
 
     @classmethod
     def all(self):
-        """Returns all documents in the collection.
+        """Return all documents in the collection.
 
         If ``sort`` has been defined on the ``Meta`` class it will be
         used to order the records.
 
-        .. versionadded:: 0.1.0
         """
 
         # All of the functionality already exists inside find(), so
@@ -114,7 +103,7 @@ class Model(object):
 
     @classmethod
     def create(cls, **fields):
-        """Creates a new document and saves it to the database.
+        """Create a new document and saves it to the database.
 
         This is a convenience method to create a new document. It will
         instantiate a new ``Model`` from the keyword arguments,
@@ -134,7 +123,6 @@ class Model(object):
         :returns: :class:`~simon.Model` -- the new document.
         :raises: :class:`TypeError`
 
-        .. versionadded:: 0.1.0
         """
 
         write_concern = {
@@ -148,7 +136,7 @@ class Model(object):
         return new
 
     def delete(self, **kwargs):
-        """Deletes a single document from the database.
+        """Delete a single document from the database.
 
         This will delete the document associated with the instance
         object. If the document does not have an ``_id``--this will
@@ -162,7 +150,6 @@ class Model(object):
         :type w: int.
         :raises: :class:`TypeError`
 
-        .. versionadded:: 0.1.0
         """
 
         id = self._document.get('_id')
@@ -184,7 +171,7 @@ class Model(object):
 
     @classmethod
     def find(cls, q=None, *qs, **fields):
-        """Gets multiple documents from the database.
+        """Return multiple documents from the database.
 
         This will find a return multiple documents matching the query
         specified through ``**fields``. If ``sort`` has been defined on
@@ -202,7 +189,6 @@ class Model(object):
         .. versionchanged:: 0.3.0
            ``qs`` is being deprecated in favor of ``q``
 
-        .. versionadded:: 0.1.0
         """
 
         if qs:
@@ -215,7 +201,7 @@ class Model(object):
 
     @classmethod
     def get(cls, q=None, *qs, **fields):
-        """Gets a single document from the database.
+        """Return a single document from the database.
 
         This will find and return a single document matching the
         query specified through ``**fields``. An exception will be
@@ -234,7 +220,6 @@ class Model(object):
         .. versionchanged:: 0.3.0
            ``qs`` is being deprecated in favor of ``q``
 
-        .. versionadded:: 0.1.0
         """
 
         if qs:
@@ -247,7 +232,7 @@ class Model(object):
 
     @classmethod
     def get_or_create(cls, **fields):
-        """Gets an existing or creates a new document.
+        """Return an existing or create a new document.
 
         This will find and return a single document matching the
         query specified through ``**fields``. If no document is found,
@@ -268,7 +253,6 @@ class Model(object):
                   document was created.
         :raises: :class:`~simon.Model.MultipleDocumentsFound`
 
-        .. versionadded:: 0.1.0
         """
 
         write_concern = {
@@ -283,7 +267,7 @@ class Model(object):
                               **fields), True
 
     def increment(self, field=None, value=1, **fields):
-        """Performs an atomic increment.
+        """Perform an atomic increment.
 
         This can be used to update a single field::
 
@@ -317,7 +301,6 @@ class Model(object):
         :type \*\*fields: \*\*kwargs.
         :raises: :class:`TypeError`, :class:`ValueError`
 
-        .. versionadded:: 0.1.0
         """
 
         write_concern = {
@@ -342,7 +325,7 @@ class Model(object):
         self._update({'$inc': update}, **write_concern)
 
     def pop(self, fields, **kwargs):
-        """Performs an atomic pop.
+        """Perform an atomic pop.
 
         Values can be popped from either the end or the beginning of a
         list. To pop a value from the end of a list, specify the name of
@@ -363,6 +346,7 @@ class Model(object):
         :raises: :class:`TypeError`
 
         .. versionadded:: 0.5.0
+
         """
 
         if not fields:
@@ -390,7 +374,7 @@ class Model(object):
         self._update({'$pop': update}, **write_concern)
 
     def pull(self, field=None, value=None, **fields):
-        """Performs an atomic pull.
+        """Perform an atomic pull.
 
         With MongoDB there are two types of pull operations: ``$pull``
         and ``$pullAll``. As the name implies, ``$pullAll`` is intended
@@ -431,6 +415,7 @@ class Model(object):
         :raises: :class:`TypeError`, :class:`ValueError`
 
         .. versionadded:: 0.5.0
+
         """
 
         write_concern = {
@@ -465,7 +450,7 @@ class Model(object):
         self._update(update, **write_concern)
 
     def push(self, field=None, value=None, allow_duplicates=True, **fields):
-        """Performs an atomic push.
+        """Perform an atomic push.
 
         With MongoDB there are three types of push operations:
         ``$push``, ``$pushAll``, add ``$addToSet``. As the name implies,
@@ -513,6 +498,7 @@ class Model(object):
         :raises: :class:`TypeError`, :class:`ValueError`
 
         .. versionadded:: 0.5.0
+
         """
 
         write_concern = {
@@ -550,7 +536,7 @@ class Model(object):
         self._update(update, **write_concern)
 
     def raw_update(self, fields, **kwargs):
-        """Performs an update using a raw document.
+        """Perform an update using a raw document.
 
         This method should be used carefully as it will perform the
         update exactly, potentially performing a full document
@@ -577,7 +563,6 @@ class Model(object):
         :type w: int.
         :raises: :class:`TypeError`
 
-        .. versionadded:: 0.1.0
         """
 
         write_concern = {
@@ -588,7 +573,7 @@ class Model(object):
         self._update(fields, **write_concern)
 
     def remove_fields(self, fields, **kwargs):
-        """Removes the specified fields from the document.
+        """Remove the specified fields from the document.
 
         The specified fields will be removed from the document in the
         database as well as the object. This operation cannot be
@@ -614,7 +599,6 @@ class Model(object):
         :type w: int.
         :raises: :class:`TypeError`
 
-        .. versionadded:: 0.1.0
         """
 
         write_concern = {
@@ -634,7 +618,7 @@ class Model(object):
         self._update({'$unset': fields}, **write_concern)
 
     def rename(self, field_from=None, field_to=None, **fields):
-        """Performs an atomic rename.
+        """Perform an atomic rename.
 
         This can be used to update a single field::
 
@@ -670,6 +654,7 @@ class Model(object):
         :raises: :class:`TypeError`, :class:`ValueError`
 
         .. versionadded:: 0.5.0
+
         """
 
         write_concern = {
@@ -694,7 +679,7 @@ class Model(object):
         self._update({'$rename': update}, **write_concern)
 
     def save(self, **kwargs):
-        """Saves the object to the database.
+        """Save the document to the database.
 
         When saving a new document for a model with ``auto_timestamp``
         set to ``True``, ``created`` will be added with the current
@@ -716,7 +701,6 @@ class Model(object):
            ``created`` is always added to inserted documents when
            ``auto_timestamp`` is ``True``
 
-        .. versionadded:: 0.1.0
         """
 
         write_concern = {
@@ -746,7 +730,7 @@ class Model(object):
         except:
             # Raise the exception that was caught
             e = sys.exc_info()
-            raise e[1], None, e[2]
+            reraise(e[0], e[1], e[2])
         else:
             # Because _update() didn't raise an exception, the created
             # and modified values can be associated with the internal
@@ -758,7 +742,7 @@ class Model(object):
                     self._document['modified'] = fields['modified']
 
     def save_fields(self, fields, **kwargs):
-        """Saves only the specified fields.
+        """Save the specified fields.
 
         If only a select number of fields need to be updated, an atomic
         update is preferred over a document replacement.
@@ -787,7 +771,6 @@ class Model(object):
         :type w: int.
         :raises: :class:`AttributeError`, :class:`TypeError`
 
-        .. versionadded:: 0.1.0
         """
 
         write_concern = {
@@ -809,7 +792,7 @@ class Model(object):
         self._update({'$set': update}, use_internal=True, **write_concern)
 
     def update(self, **fields):
-        """Performs an atomic update.
+        """Perform an atomic update.
 
         If only a select number of fields need to be updated, an atomic
         update is preferred over a document replacement.
@@ -833,7 +816,6 @@ class Model(object):
         :type \*\*fields: \*\*kwargs.
         :raises: :class:`TypeError`
 
-        .. versionadded:: 0.1.0
         """
 
         write_concern = {
@@ -847,7 +829,7 @@ class Model(object):
 
     @classmethod
     def _find(cls, q=None, find_one=False, **fields):
-        """Find documents in the database.
+        """Return documents in the database.
 
         This method will find documents in the database matching the
         specified query. When ``find_one`` is set to ``False``, a
@@ -878,6 +860,7 @@ class Model(object):
            ``_id`` can be a type other than :class:`~pymongo.ObjectId`
 
         .. versionadded:: 0.3.0
+
         """
 
         # If there is a Q object, add it to the spec document.
@@ -965,13 +948,14 @@ class Model(object):
            ``safe`` is being deprecated in favor of ``w`` (PyMongo 2.4+)
 
         .. versionadded:: 0.3.0
+
         """
 
         # Save characters
         cls = self.__class__
 
         def check_typed_fields(fields):
-            """Checks that fields are of the correct type.
+            """Check that fields are of the correct type.
 
             This function checks the fields that are being saved and
             makes sure they are of the correct type. If a field isn't
@@ -982,6 +966,7 @@ class Model(object):
             :raises: :class:`TypeError`
 
             .. versionadded:: 0.6.0
+
             """
 
             for k, v in cls._meta.typed_fields.items():
@@ -1010,7 +995,7 @@ class Model(object):
                 raise TypeError(message)
 
         def map_field_names_and_values(fields):
-            """Maps field names and values.
+            """Map field names and values.
 
             This function will take care of mapping the keys of
             ``fields`` to the correct syntax for the query.
@@ -1026,13 +1011,14 @@ class Model(object):
             :raises: :class:`AttributeError`
 
             .. versionadded:: 0.3.0
+
             """
 
             fields = map_fields(cls._meta.field_map, fields, flatten_keys=True)
             if use_internal:
                 try:
                     fields = dict((k, get_nested_key(self._document, k))
-                                  for k in fields.iterkeys())
+                                  for k in fields)
                 except KeyError:
                     # KeyError will be raised by get_nested_key() when a
                     # field isn't part of the internal document.
@@ -1066,7 +1052,7 @@ class Model(object):
                     for field_from, field_to in fields[k].items():
                         mapped = map_fields(cls._meta.field_map, {field_to: 1},
                                             flatten_keys=True)
-                        fields[k][field_from] = mapped.keys()[0]
+                        fields[k][field_from] = get_next(iterkeys(mapped))()
         else:
             fields = map_field_names_and_values(fields)
         # When placing fields in kwargs, make a copy so changes to
@@ -1116,7 +1102,7 @@ class Model(object):
                         # this blocking operation, renaming to a typed
                         # field will trigger a UserWarning instead.
                         if any(v in cls._meta.typed_fields
-                               for v in v.itervalues()):
+                               for v in itervalues(v)):
                             message = ('You are renaming a typed field. Its '
                                        'value may not be of the correct type.')
                             warnings.warn(message, UserWarning)
@@ -1179,19 +1165,18 @@ class Model(object):
             if rename:
                 # The old fields need to be removed. The new fields will
                 # be added through the find_one() below.
-                for k in rename.iterkeys():
+                for k in rename:
                     if '.' in k:
                         self._document = remove_nested_key(self._document, k)
                     else:
                         self._document.pop(k, None)
-                fields['$rename'] = dict((v, 1) for v in rename.itervalues())
+                fields['$rename'] = dict((v, 1) for v in itervalues(rename))
 
             # If the only operation was an $unset, we're done.
             if not fields:
                 return
 
-            fields = dict((k, 1) for v in fields.itervalues()
-                          for k in v.iterkeys())
+            fields = dict((k, 1) for v in itervalues(fields) for k in v)
             doc = self._meta.db.find_one({'_id': id}, fields)
 
             # There's no need to update the _id
@@ -1213,7 +1198,7 @@ class Model(object):
     # Attribute access methods
 
     def __delattr__(self, name):
-        """Remove a key from the document"""
+        """Remove a key from the document."""
 
         # Normally name can be used here. In this instance, however,
         # name is needed to remove the attribute from the object.
@@ -1222,12 +1207,6 @@ class Model(object):
         key = self._meta.field_map.get(name, name)
         if key in self._document:
             del self._document[key]
-            try:
-                delattr(self, name)
-            except AttributeError:
-                # This will happen if the attribute hasn't been directly
-                # accessed yet.
-                pass
 
             # The deletion of the attribute is now complete, get out
             # before an AttributeError is raised by the super delete.
@@ -1236,7 +1215,7 @@ class Model(object):
         object.__delattr__(self, name)
 
     def __getattr__(self, name):
-        """Retrieve a value from the document"""
+        """Return a value from the document."""
 
         # The first thing to look for is nested keys
         if '__' in name or '.' in name:
@@ -1246,24 +1225,23 @@ class Model(object):
                 # dict.
                 mapped_name = map_fields(self.__class__._meta.field_map,
                                          {name: 1}, flatten_keys=True)
-                mapped_name = mapped_name.keys()[0]
+                mapped_name = get_next(iterkeys(mapped_name))()
             else:
                 mapped_name = name
-            try:
+
+            with ignored(AttributeError):
+                # If not, give it a go the normal way.
                 return get_nested_key(self._document, mapped_name)
-            except AttributeError:
-                # Give it a go the normal way
-                pass
 
         # If the attribute is a key in the document, use it.
         name = self._meta.field_map.get(name, name)
         if not name in self._document:
-            raise AttributeError("'{0}' object has no attribute '{1}'.".format(
-                self.__class__.__name__, name))
+            message = "'{0}' object has no attribute '{1}'."
+            raise AttributeError(message.format(self.__class__.__name__, name))
         return self._document[name]
 
     def __setattr__(self, name, value):
-        """Set a document value"""
+        """Set a document value."""
 
         # Do not allow _meta to be overwritten
         if name == '_meta':
@@ -1282,7 +1260,7 @@ class Model(object):
             # dict.
             mapped_name = map_fields(self.__class__._meta.field_map, {name: 1},
                                      flatten_keys=True)
-            mapped_name = mapped_name.keys()[0]
+            mapped_name = get_next(iterkeys(mapped_name))()
 
             # Build a dictionary that can be applied to the internal
             # document dictionary with update_nested_keys().  Do this
@@ -1298,7 +1276,7 @@ class Model(object):
     # Rich comparison methods
 
     def __eq__(a, b):
-        """Check equality of two instances"""
+        """Check equality of two instances."""
 
         # If either b isn't of the right type, a and b use different
         # database connections, or a and b use different collections,
@@ -1321,14 +1299,14 @@ class Model(object):
         return a_id == b_id
 
     def __ne__(a, b):
-        """Check inequality of two instances"""
+        """Check inequality of two instances."""
 
         return not a.__eq__(b)
 
     # Container methods
 
     def __contains__(self, name):
-        """Check for a key in a document"""
+        """Check for a key in a document."""
 
         key = self._meta.field_map.get(name, name)
         return key in self._document
