@@ -10,14 +10,39 @@ compatability of its API.
 import collections
 from datetime import datetime
 import warnings
+try:
+    # @raymondh added the ignored() context manager in Python 3.4:
+    # http://hg.python.org/cpython/rev/406b47c64480.
+    # It's awesome and I want to use it...
+    from contextlib import ignored
+except ImportError:
+    from contextlib import contextmanager
+
+    # ... but if this is running on an older version of Python--
+    # especially since 3.4 hasn't been released yet at the time of this
+    # change--I'm adding it in manually. The following is taken directly
+    # from Lib/contextlib.py.
+
+    @contextmanager
+    def ignored(*exceptions):
+        """Context manager to ignore specifed exceptions
+
+             with ignored(OSError):
+                 os.remove(somefile)
+
+        """
+        try:
+            yield
+        except exceptions:
+            pass
 
 from bson import ObjectId
 
 from .connection import pymongo_supports_mongoclient
 
 __all__ = ('current_datetime', 'get_nested_key', 'guarantee_object_id',
-           'is_atomic', 'map_fields', 'parse_kwargs', 'remove_nested_key',
-           'set_write_concern', 'update_nested_keys')
+           'ignored', 'is_atomic', 'map_fields', 'parse_kwargs',
+           'remove_nested_key', 'set_write_concern', 'update_nested_keys')
 
 
 # The logical operators are needed when mapping fields. The values
@@ -27,26 +52,27 @@ _logicals = ('$and', '$or')
 
 
 def current_datetime():
-    """Gets the current datetime in UTC formatted for MongoDB
+    """Get the current datetime in UTC formatted for MongoDB.
 
     Python includes microseconds in its ``datetime`` values. MongoDB,
     on the other hand, only retains them down to milliseconds. This
-    method will not only get the current time in UTC, but it will also
+    function will not only get the current time in UTC, but it will also
     remove microseconds from the value.
 
     :returns: datetime -- the current datetime formatted for MongoDB.
 
     .. versionadded:: 0.2.0
+
     """
 
     now = datetime.utcnow()
-    return now.replace(microsecond=(now.microsecond / 1000 * 1000))
+    return now.replace(microsecond=(now.microsecond // 1000 * 1000))
 
 
 def get_nested_key(values, key):
-    """Gets a value for a nested dictionary key.
+    """Get a value for a nested dictionary key.
 
-    This method can be used to retrieve the value nested within a
+    This function can be used to retrieve the value nested within a
     dictionary. The entire path should be provided as the value for
     ``key``, using a ``.`` as the delimiter
     (e.g., ``'path.to.the.key``').
@@ -62,7 +88,6 @@ def get_nested_key(values, key):
     :returns: The value associated with the nested key.
     :raises: :class:`KeyError`
 
-    .. versionadded:: 0.1.0
     """
 
     # If key exists in values, return its value, otherwise recurse
@@ -83,9 +108,9 @@ def get_nested_key(values, key):
 
 
 def guarantee_object_id(value):
-    """Converts a value into an Object ID.
+    """Convert a value into an Object ID.
 
-    This method will convert a value to an :class:`ObjectId`. If
+    This function will convert a value to an :class:`ObjectId`. If
     ``value`` is a ``dict`` (e.g., with a comparison operator as the key
     ), the value in the ``dict`` will be converted. Any values that are
     a ``list`` or ``tuple`` will be iterated over, and replaced with a
@@ -103,7 +128,6 @@ def guarantee_object_id(value):
     :returns: ObjectId or dict -- the Object ID.
     :raises: :class:`TypeError`, :class:`~bson.errors.InvalidId`
 
-    .. versionadded:: 0.1.0
     """
 
     # If it's already an Object ID, get out early.
@@ -135,9 +159,9 @@ def guarantee_object_id(value):
 
 
 def is_atomic(document):
-    """Checks for atomic update operators.
+    """Check for atomic update operators.
 
-    This method checks for operators in ``document``. If a spec
+    This function checks for operators in ``document``. If a spec
     document is provided instead of a document to save or update, a
     false positive will be reported if a logical operator such as
     ``$and`` or ``$or`` is used.
@@ -148,17 +172,18 @@ def is_atomic(document):
               update.
 
     .. versionadded:: 0.3.0
+
     """
 
-    return any(k[0] == '$' for k in document.iterkeys())
+    return any(k[0] == '$' for k in document)
 
 
 def map_fields(field_map, fields, with_operators=False, flatten_keys=False):
-    """Maps attribute names to document keys.
+    """Map attribute names to document keys.
 
     Attribute names will be mapped to document keys using the mapping
     specified in ``field_map``. If any of the attribute names contain
-    ``__``, :meth:`parse_kwargs` will be called and a second pass
+    ``__``, :func:`parse_kwargs` will be called and a second pass
     through ``cls._meta.field_map`` will be performed.
 
     The two-pass approach is used to allow for keys in embedded
@@ -169,7 +194,7 @@ def map_fields(field_map, fields, with_operators=False, flatten_keys=False):
     The ``$and`` and ``$or`` operators cannot be mapped to different
     keys. Any occurrences of these operators as keys should be
     accompanied by a ``list`` of ``dict``s. Each ``dict`` will be put
-    back into :meth:`map_fields` to ensure that keys nested within
+    back into :func:`map_fields` to ensure that keys nested within
     boolean queries are mapped properly.
 
     If ``with_operators`` is set, the following operators will be
@@ -190,6 +215,19 @@ def map_fields(field_map, fields, with_operators=False, flatten_keys=False):
     * ``$elemMatch`` the key's value is an array satisfying the given
       query
 
+    The following aggregation operators are also supported:
+
+    * ``$addToSet`` returns an unique array of all values found in the
+      selected field
+    * ``$push`` returns an array of all values found in the selected
+      field
+    * ``$first`` returns the first value encountered for its group
+    * ``$last`` returns the last value encountered for its group
+    * ``$max`` returns the hightest value for the field
+    * ``$min`` returns the lowest non-null value for the field
+    * ``$avg`` returns the average value for the field
+    * ``$sum`` returns the sum of values for the field
+
     To utilize any of the operators, append ``__`` and the name of the
     operator sans the ``$`` (e.g., ``__gt``, ``__lt``) to the name of
     the key::
@@ -228,12 +266,18 @@ def map_fields(field_map, fields, with_operators=False, flatten_keys=False):
     :returns: dict -- key/value pairs renamed based on ``cls``'s
               ``field_map`` mapping.
 
-    .. versionadded:: 0.1.0
+    .. versionchanged:: 0.7.0
+       ``$group`` operators are supported
+       All lowercase operators are supported
+
     """
 
     if with_operators:
-        operators = ('all', 'elemMatch', 'exists', 'gt', 'gte', 'in', 'lt',
-                     'lte', 'ne', 'near', 'nin', 'size')
+        operators = ('addToSet', 'addtoset', 'all', 'avg', 'elemMatch',
+                     'elemmatch', 'exists', 'first', 'gt', 'gte', 'in', 'last',
+                     'lt', 'lte', 'max', 'min', 'ne', 'near', 'nin', 'push',
+                     'size', 'sum')
+        operators_cased = {'addtoset': 'addToSet', 'elemmatch': 'elemMatch'}
 
         for k, v in fields.items():
             # To figure out if a key includes an operator, split it
@@ -255,6 +299,14 @@ def map_fields(field_map, fields, with_operators=False, flatten_keys=False):
                         v = {'${0}'.format(operator[1]): v}
                         operator = operator[0].rstrip('__not'), 'not'
 
+                    # Operators are case sensitive as camel case.
+                    # Because the operators are intended to be used as
+                    # kwargs, writing them as such will appear out of
+                    # place. This check allows the operators to be
+                    # specified using lowercase.
+                    if operator[1] in operators_cased:
+                        operator[1] = operators_cased[operator[1]]
+
                     fields[operator[0]] = {'${0}'.format(operator[1]): v}
                     del fields[k]
 
@@ -322,7 +374,7 @@ def map_fields(field_map, fields, with_operators=False, flatten_keys=False):
 
 
 def parse_kwargs(**kwargs):
-    """Parses embedded documents from dictionary keys.
+    """Parse embedded documents from dictionary keys.
 
     This takes a kwargs dictionary whose keys contain ``__`` and convert
     them to a new dictionary with new keys created by splitting the
@@ -333,7 +385,6 @@ def parse_kwargs(**kwargs):
     :returns: dict -- dictionary with nested keys generated from the
               names of the arguments.
 
-    .. versionadded:: 0.1.0
     """
 
     parsed_kwargs = {}
@@ -364,11 +415,11 @@ def parse_kwargs(**kwargs):
 
 
 def remove_nested_key(original, key):
-    """Removes keys within a nested dictionary.
+    """Remove keys within a nested dictionary.
 
-    This method can remove a key from within a nested dictionary. Nested
-    keys should be specified using a ``.`` as the delimiter. If no
-    delimiter is found, the key will be removed from the root
+    This function can remove a key from within a nested dictionary.
+    Nested keys should be specified using a ``.`` as the delimiter. If
+    no delimiter is found, the key will be removed from the root
     dictionary.
 
     If ``original`` is not a dictionary, a :class:`TypeError` will be
@@ -382,11 +433,10 @@ def remove_nested_key(original, key):
     :returns: dict -- the updated dictionary
     :raises: :class:`TypeError`, :class:`KeyError`
 
-    .. versionadded:: 0.1.0
     """
 
     if not isinstance(original, collections.Mapping):
-        raise TypeError('`original` must be a `dict`.')
+        raise TypeError("'original' must be a dict.")
 
     if '.' in key:
         # If the key contains a . it is considered nested. Split the key
@@ -403,7 +453,7 @@ def remove_nested_key(original, key):
 
 
 def set_write_concern_as_safe(options, force_write_concern):
-    """Sets the safe parameter for write concern.
+    """Set the safe parameter for write concern.
 
     If ``force_write_concern`` is ``True``, write concern will be used.
 
@@ -413,6 +463,7 @@ def set_write_concern_as_safe(options, force_write_concern):
     :type force_write_concern: bool.
 
     .. versionadded:: 0.6.0
+
     """
 
     safe = options.pop('safe', None)
@@ -429,7 +480,7 @@ def set_write_concern_as_safe(options, force_write_concern):
 
 
 def set_write_concern_as_w(options, force_write_concern):
-    """Sets the w parameter for write concern.
+    """Set the w parameter for write concern.
 
     If ``force_write_concern`` is a value greater than zero, write
     concern will be used.
@@ -440,6 +491,7 @@ def set_write_concern_as_w(options, force_write_concern):
     :type force_write_concern: int.
 
     .. versionadded:: 0.6.0
+
     """
 
     if 'safe' in options and options['safe'] is not None:
@@ -468,9 +520,9 @@ else:
 
 
 def update_nested_keys(original, updates):
-    """Updates keys within nested dictionaries.
+    """Update keys within nested dictionaries.
 
-    This method simulates merging two dictionaries. It allows specific
+    This function simulates merging two dictionaries. It allows specific
     keys within a dictionary or nested dictionary without overwriting
     the the entire dictionary.
 
@@ -484,7 +536,6 @@ def update_nested_keys(original, updates):
     :returns: dict -- the updated dictionary.
     :raises: :class:`TypeError`
 
-    .. versionadded:: 0.1.0
     """
 
     # Based on http://stackoverflow.com/questions/3232943/
