@@ -10,7 +10,7 @@ from bson.errors import InvalidId
 import pymongo
 
 from simon.utils import (current_datetime, get_nested_key, guarantee_object_id,
-                         is_atomic, map_fields, parse_kwargs,
+                         ignored, is_atomic, map_fields, parse_kwargs,
                          remove_nested_key, set_write_concern,
                          set_write_concern_as_safe, set_write_concern_as_w,
                          update_nested_keys)
@@ -186,6 +186,55 @@ class TestUtils(unittest.TestCase):
         actual = map_fields(field_map, {'x': 1, 'y': 2})
         self.assertEqual(actual, expected)
 
+    def test_map_fields_aggregation_operators(self):
+        """Test the `map_fields()` method with aggregation operators."""
+
+        expected = {'a': {'$addToSet': 'b'}}
+        actual = map_fields(field_map, {'a__addToSet': 'b'},
+                            with_operators=True)
+        self.assertEqual(actual, expected)
+
+        expected = {'a': {'$avg': 'b'}}
+        actual = map_fields(field_map, {'a__avg': 'b'}, with_operators=True)
+        self.assertEqual(actual, expected)
+
+        expected = {'a': {'$first': 'b'}}
+        actual = map_fields(field_map, {'a__first': 'b'}, with_operators=True)
+        self.assertEqual(actual, expected)
+
+        expected = {'a': {'$last': 'b'}}
+        actual = map_fields(field_map, {'a__last': 'b'}, with_operators=True)
+        self.assertEqual(actual, expected)
+
+        expected = {'a': {'$max': 'b'}}
+        actual = map_fields(field_map, {'a__max': 'b'}, with_operators=True)
+        self.assertEqual(actual, expected)
+
+        expected = {'a': {'$min': 'b'}}
+        actual = map_fields(field_map, {'a__min': 'b'}, with_operators=True)
+        self.assertEqual(actual, expected)
+
+        expected = {'a': {'$push': 'b'}}
+        actual = map_fields(field_map, {'a__push': 'b'}, with_operators=True)
+        self.assertEqual(actual, expected)
+
+        expected = {'a': {'$sum': 'b'}}
+        actual = map_fields(field_map, {'a__sum': 'b'}, with_operators=True)
+        self.assertEqual(actual, expected)
+
+    def test_map_fields_cased_operators(self):
+        """Test the `map_fields()` with operators that are cased."""
+
+        expected = {'a': {'$addToSet': 'b'}}
+        actual = map_fields(field_map, {'a__addtoset': 'b'},
+                            with_operators=True)
+        self.assertEqual(actual, expected)
+
+        expected = {'a': {'$elemMatch': {'b': 2}}}
+        actual = map_fields(field_map, {'a__elemmatch': {'b': 2}},
+                            with_operators=True)
+        self.assertEqual(actual, expected)
+
     def test_map_fields_flattened_keys(self):
         """Test the `map_fields()` method with `flatten_keys` set."""
 
@@ -616,3 +665,28 @@ class TestUtils(unittest.TestCase):
 
         with self.assertRaises(TypeError):
             update_nested_keys(1, 1)
+
+
+# The below is taken directly from Lib/test/test_contextlib.py as of
+# http://hg.python.org/cpython/rev/406b47c64480.
+class TestIgnored(unittest.TestCase):
+
+    def test_no_exception(self):
+
+        with ignored(ValueError):
+            self.assertEqual(pow(2, 5), 32)
+
+    def test_exact_exception(self):
+
+        with ignored(TypeError):
+            len(5)
+
+    def test_multiple_exception_args(self):
+
+        with ignored(ZeroDivisionError, TypeError):
+            len(5)
+
+    def test_exception_hierarchy(self):
+
+        with ignored(LookupError):
+            'Hello'[50]
